"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const isNode_1 = require("./isNode");
const detectTimerResolution_1 = require("./detectTimerResolution");
const noop_1 = require("./noop");
const measureNode = (test) => {
    const t0 = process.hrtime.bigint();
    test();
    const t1 = process.hrtime.bigint();
    return Number(t1 - t0 - noop_1.default.val);
};
const measureBrowser = (test) => {
    const t0 = performance.now();
    test();
    const t1 = performance.now();
    return t1 - t0 - noop_1.default.val;
};
const getTimer = () => {
    const resolution = (0, detectTimerResolution_1.default)();
    if (isNode_1.default) {
        let start;
        return {
            measure: measureNode,
            init() {
                start = process.hrtime.bigint();
            },
            since() {
                return Number(process.hrtime.bigint() - start) / 1e9;
            },
            resolution,
        };
    }
    let start;
    return {
        measure: measureBrowser,
        init() {
            start = performance.now();
        },
        since() {
            return (performance.now() - start) / 1e3;
        },
        resolution,
    };
};
exports.default = getTimer();
